function [RawData,BasisData, ReferPeptideIndex] = BuildModel(PeptideInfo,PeptideMass, PeptideIntensity, RawFileDir, RawFileDirList, RawFileIndex)
% Input
% PeptideInfo:          The charge state, scan of ms/ms spectrum to identify the peptide, etc
% PeptideMass:          The theoretic isotopic mass values for each peptide
% PeptideIntensity:     The theoretic isotopic intensities for each peptide
% RawFileDir:           The directory for the decoded MS spectra
% RawFileDirList:       MS spectra file list
% RawFileIndex:         The index of the MS spectrum that need to build the model with
% Output
% RawData:              The stick version of the origial MS spectrum
% BasisData:            The bases for the MS spectrum
% ReferPeptideIndex:    The index of the reference code for each peptide

if RawFileDir(end) ~= '/'
    RawFileDir = [RawFileDir, '/'];
end
% Estimate the basis
[basis_mz, basis_intensity, refer_peptide_index] = GenerateBasis(PeptideInfo,PeptideMass, PeptideIntensity, RawFileDir, RawFileDirList, RawFileIndex);

if isempty(basis_mz) == 1
    RawData = [];
    BasisData = [];
    ReferPeptideIndex = [];
    return;
end


analyze_mz = basis_mz;
analyze_intensity = basis_intensity;

ReferPeptideIndex = refer_peptide_index;
raw_data = load([RawFileDir, num2str(RawFileIndex), '.txt']);
raw_ms_mz  = raw_data(:,1);
raw_ms_intensity = raw_data(:,2);

RawData = zeros(length(raw_ms_mz), 1);
BasisData = zeros(length(raw_ms_mz), size(basis_mz, 2));

for row_index=1:size(basis_mz, 2)
    for col_index=1:3
        sel_mz = analyze_mz(col_index, row_index);
        abs_distance = abs(raw_ms_mz - sel_mz);
        if min(abs_distance) > 0.2
            disp('Miss match peak');
        end
        peak_index = find(abs_distance == min(abs_distance), 1, 'first');
        RawData(peak_index) = raw_ms_intensity(peak_index);
        BasisData(peak_index, row_index) = analyze_intensity(col_index, row_index);
    end
end

sum_buffer = sum(BasisData, 2);
remove_index = (sum_buffer == 0);
RawData(remove_index) = [];
BasisData(remove_index, :) = [];