function DataAnalyze(BaseFileName, DatabaseSearching, Threshold, Lamda)
% Input
% BaseFileName:             The base filename for the analyzed file
% DatabaseSearching:        The directory for the database searching result
% Threshold:                The threshold to select the peptides that to be analyzed
% Lamda:                    The parameter to control the tradoff beween the smoothness of the estimation and its fit to raw data

if length(Threshold) ~= 2
   disp('Error threshold value');
   return;
end

if DatabaseSearching(end) ~= '/'
   DatabaseSearching = [DatabaseSearching, '/'];
end

data_base_thresh = Threshold;
lamda = Lamda;

raw_file_dir = [BaseFileName, '/'];
save_dir = [BaseFileName, '_res/'];
mkdir(save_dir);

file_list = dir([raw_file_dir, '*.txt']);
level_one_list = zeros(1, length(file_list));

for file_index=1:length(file_list)
    file_name = file_list(file_index).name;
    end_index = find(file_name == '.');
    level_one_list(file_index) = str2double(file_name(1:end_index-1));
end
level_one_list = sort(level_one_list);


%analyze database search result
[peptide_mass, peptide_intensity, peptide_info, analyze_peptide_refer] = AnalyzeDatabaseResult(DatabaseSearching, BaseFileName, data_base_thresh);

m = [];
n = max(1000, size(peptide_mass, 2));
A=[];
k = [];
y = [];

select_index = level_one_list;
k = size(peptide_info, 1);
m = length(select_index);
disp('The number of scans selected:');
disp(length(select_index));

% Load data from file
disp('Begin to load data ...');
region_constrain_matrix = sparse(k, m);

y = zeros(n * m, 1);
filling_data = sparse(n, k);
filling_data(n-k+1:n,:) = 100 * eye(k);

tic;
for file_index=1:m
    disp(['Loading data index:', num2str(file_index)]);
    [raw_data, basis_data, refer_list] = BuildModel(peptide_info,peptide_mass, peptide_intensity, raw_file_dir, level_one_list, level_one_list(file_index));
    if length(raw_data) >= n
        disp(length(raw_data));
        return;
    end
    tmp_y = sparse(n,1);
    tmp_y(1:length(raw_data)) = raw_data;
    y( (file_index - 1)*n + 1 : file_index * n) = tmp_y;
    sparse_basis = sparse(n, k);
    tmp_saving_list=1:k;
    for refer_index = 1:length(refer_list)
        tmp_saving_list(refer_list(refer_index)) = 0;
        sparse_basis(1:length(raw_data), refer_list(refer_index)) = basis_data(:, refer_index);
        region_constrain_matrix(refer_list(refer_index), file_index) = 1;
    end
    tmp_saving_list(tmp_saving_list==0) = [];
    sparse_basis(:, tmp_saving_list) = filling_data(:, tmp_saving_list);
    A = blkdiag(A, sparse_basis);
    A = sparse(A);
end
toc;

clc;
region_constrain_matrix = reshape(region_constrain_matrix, 1, k * m);
for i=1:size(A,2)
    sel_col_a = A(:,i);
    if max(sel_col_a) < 30
        region_constrain_matrix(i) = 0;
    end
end
non_zeros_index = (region_constrain_matrix == 1);

disp('Begin to solve the problem....');

row_i = 1:(k*m-k);
col_j = 1:(k * m -k);
s_value = ones(1, k*m-k);
row_i = [row_i 1:k*m-k];
col_j = [col_j col_j + k];
s_value = [s_value -1 * s_value];
D = sparse(row_i, col_j, s_value, k*m - k, k * m);

clear prob;
prob.cfix = 0.5 * y' * y;
[prob.qosubi, prob.qosubj , prob.qoval] = find(sparse(tril(A'*A)));
[prob.qcsubi,prob.qcsubj, prob.qcval] = find(sparse(tril(2 * D' * D)));
prob.qcsubk = ones(length(prob.qcsubi), 1);
prob.c = -A' * y;
prob.a = sparse(1, k * m);
prob.blc = [];
prob.buc = [];
prob.blx = sparse(k * m, 1);
upper_bound = sparse(k * m,1);
upper_bound(non_zeros_index) = inf;
prob.bux = upper_bound;
[r,res] = mosekopt('minimize',prob);

x=res.sol.itr.xx;
norm_constraint = x'*D'*D*x;

prob.buc = lamda * norm_constraint;
[r,res] = mosekopt('minimize',prob);

x = res.sol.itr.xx;
x=reshape(x, k, m);

disp('Saving analyze result.....');
for i=1:k
    disp(i);
    file_name = [save_dir, num2str(i), '.txt'];
    fid = fopen(file_name,'w');
    fprintf(fid, '%f\n', x(i,:));
    fclose(fid);
end
file_name = [save_dir, 'refer.txt'];
fid=fopen(file_name,'w');
fprintf(fid, '%d\n', analyze_peptide_refer');
fclose(fid);